@@ -34,8 +34,7 @@
 
 using namespace Akregator;
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMAkregatorAdvancedConfigFactory, "akregator_config_advanced.json", registerPlugin<KCMAkregatorAdvancedConfig>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorAdvancedConfig, "akregator_config_advanced.json")
 
 KCMAkregatorAdvancedConfig::KCMAkregatorAdvancedConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
