@@ -43,7 +43,7 @@ class TreeNode;
 struct ArticleId {
     QString feedUrl;
     QString guid;
-    bool operator<(const ArticleId &other) const
+    Q_REQUIRED_RESULT bool operator<(const ArticleId &other) const
     {
         return feedUrl < other.feedUrl || (feedUrl == other.feedUrl && guid < other.guid);
     }
@@ -56,7 +56,7 @@ class AKREGATOR_EXPORT CompositeJob : public KCompositeJob
     Q_OBJECT
 public:
     explicit CompositeJob(QObject *parent = nullptr);
-    bool addSubjob(KJob *job) override;
+    Q_REQUIRED_RESULT bool addSubjob(KJob *job) override;
     void start() override;
 };
 
