@@ -74,7 +74,7 @@ bool SortColorizeProxyModel::filterAcceptsRow(int source_row, const QModelIndex
         return false;
     }
 
-    for (uint i = 0; i < m_matchers.size(); ++i) {
+    for (uint i = 0, total = m_matchers.size(); i < total; ++i) {
         if (!static_cast<ArticleModel *>(sourceModel())->rowMatches(source_row, m_matchers[i])) {
             return false;
         }
@@ -349,22 +349,14 @@ void ArticleListView::startResizingTitleColumn()
     // Interactive so that the user can still resize the column himself if he
     // wants to
     header()->setSectionResizeMode(ArticleModel::ItemTitleColumn, QHeaderView::Stretch);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     QMetaObject::invokeMethod(this, &ArticleListView::finishResizingTitleColumn, Qt::QueuedConnection);
-#else
-    QMetaObject::invokeMethod(this, "finishResizingTitleColumn", Qt::QueuedConnection);
-#endif
 }
 
 void ArticleListView::finishResizingTitleColumn()
 {
     if (QApplication::mouseButtons() != Qt::NoButton) {
         // Come back later: user is still resizing the widget
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
         QMetaObject::invokeMethod(this, &ArticleListView::finishResizingTitleColumn, Qt::QueuedConnection);
-#else
-        QMetaObject::invokeMethod(this, "finishResizingTitleColumn", Qt::QueuedConnection);
-#endif
         return;
     }
     header()->setSectionResizeMode(QHeaderView::Interactive);
