@@ -19,7 +19,6 @@
 
 #include "articleviewerwebenginepage.h"
 #include <QWebEngineSettings>
-#include <QWebEngineProfile>
 #include <actionmanager.h>
 #include <WebEngineViewer/ZoomActionMenu>
 
@@ -27,8 +26,8 @@
 
 using namespace Akregator;
 
-ArticleViewerWebEnginePage::ArticleViewerWebEnginePage(QWebEngineProfile *profile, QObject *parent)
-    : WebEngineViewer::WebEnginePage(profile, parent)
+ArticleViewerWebEnginePage::ArticleViewerWebEnginePage(QObject *parent)
+    : WebEngineViewer::WebEnginePage(parent)
 {
     settings()->setAttribute(QWebEngineSettings::AutoLoadImages, true);
 
