@@ -29,8 +29,6 @@
 
 #include <QDateTime>
 #include <QHash>
-#include <QList>
-#include <QMap>
 #include <QString>
 #include <QStringList>
 
