@@ -102,7 +102,6 @@ public:
     QString m_htmlUrl;
     QString m_description;
     QString m_comment;
-    QString m_faviconUrl;
 
     /** list of feed articles */
     QHash<QString, Article> articles;
@@ -116,13 +115,12 @@ public:
     QVector<Article> m_removedArticlesNotify;
     QVector<Article> m_updatedArticlesNotify;
 
-    QPixmap m_imagePixmap;
+    Feed::ImageInfo m_logoInfo;
+    Feed::ImageInfo m_faviconInfo;
+
     QIcon m_favicon;
     mutable int m_totalCount;
-    void setTotalCountDirty() const
-    {
-        m_totalCount = -1;
-    }
+    void setTotalCountDirty() const;
 };
 
 QString Feed::archiveModeToString(ArchiveMode mode)
@@ -168,11 +166,32 @@ Akregator::Feed *Feed::fromOPML(const QDomElement &e, Backend::Storage *storage)
     const bool loadLinkedWebsite = e.attribute(QStringLiteral("loadLinkedWebsite")) == QLatin1String("true");
     const QString comment = e.attribute(QStringLiteral("comment"));
     const QString faviconUrl = e.attribute(QStringLiteral("faviconUrl"));
+    Feed::ImageInfo faviconInfo;
+    faviconInfo.imageUrl = faviconUrl;
+    if (e.hasAttribute(QStringLiteral("faviconWidth"))) {
+        faviconInfo.width = e.attribute(QStringLiteral("faviconWidth")).toInt();
+    }
+    if (e.hasAttribute(QStringLiteral("faviconHeight"))) {
+        faviconInfo.height = e.attribute(QStringLiteral("faviconHeight")).toInt();
+    }
+
+    Feed::ImageInfo logoInfo;
+    const QString logoUrl = e.attribute(QStringLiteral("logoUrl"));
+    logoInfo.imageUrl = logoUrl;
+    if (e.hasAttribute(QStringLiteral("logoWidth"))) {
+        logoInfo.width = e.attribute(QStringLiteral("logoWidth")).toInt();
+    }
+    if (e.hasAttribute(QStringLiteral("logoHeight"))) {
+        logoInfo.height = e.attribute(QStringLiteral("logoHeight")).toInt();
+    }
+
     const uint id = e.attribute(QStringLiteral("id")).toUInt();
 
     Feed *const feed = new Feed(storage);
     feed->setTitle(title);
-    feed->setFaviconUrl(faviconUrl);
+    feed->setFaviconInfo(faviconInfo);
+    feed->setLogoInfo(logoInfo);
+
     feed->setXmlUrl(xmlUrl);
     feed->setCustomFetchIntervalEnabled(useCustomFetchInterval);
     feed->setHtmlUrl(htmlUrl);
@@ -255,7 +274,7 @@ void Feed::loadArticles()
         d->m_archive = d->m_storage->archiveFor(xmlUrl());
     }
 
-    QStringList list = d->m_archive->articles();
+    const QStringList list = d->m_archive->articles();
     for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it) {
         Article mya(*it, this, d->m_archive);
         d->articles[mya.guid()] = mya;
@@ -331,6 +350,11 @@ Feed::Private::Private(Backend::Storage *storage_, Akregator::Feed *qq)
     Q_ASSERT(m_storage);
 }
 
+void Feed::Private::setTotalCountDirty() const
+{
+    m_totalCount = -1;
+}
+
 Feed::Feed(Backend::Storage *storage) : TreeNode()
     , d(new Private(storage, this))
 {
@@ -442,9 +466,9 @@ bool Feed::loadLinkedWebsite() const
     return d->m_loadLinkedWebsite;
 }
 
-QPixmap Feed::image() const
+Feed::ImageInfo Feed::logoInfo() const
 {
-    return d->m_imagePixmap;
+    return d->m_logoInfo;
 }
 
 QString Feed::xmlUrl() const
@@ -470,15 +494,21 @@ void Feed::setHtmlUrl(const QString &s)
     d->m_htmlUrl = s;
 }
 
-QString Feed::faviconUrl() const
+Feed::ImageInfo Feed::faviconInfo() const
 {
-    return d->m_faviconUrl;
+    return d->m_faviconInfo;
 }
 
 void Feed::setFaviconUrl(const QString &url)
 {
-    d->m_faviconUrl = url;
-    setFavicon(QIcon(url));
+    d->m_faviconInfo.imageUrl = url;
+    setFavicon(QIcon(d->m_faviconInfo.imageUrl));
+}
+
+void Feed::setFaviconInfo(const Feed::ImageInfo &info)
+{
+    d->m_faviconInfo = info;
+    setFavicon(QIcon(info.imageUrl));
 }
 
 QString Feed::description() const
@@ -530,7 +560,24 @@ QDomElement Feed::toOPML(QDomElement parent, QDomDocument document) const
     if (d->m_loadLinkedWebsite) {
         el.setAttribute(QStringLiteral("loadLinkedWebsite"), QStringLiteral("true"));
     }
-    el.setAttribute(QStringLiteral("faviconUrl"), d->m_faviconUrl);
+    if (!d->m_faviconInfo.imageUrl.isEmpty()) {
+        el.setAttribute(QStringLiteral("faviconUrl"), d->m_faviconInfo.imageUrl);
+        if (d->m_faviconInfo.width != -1) {
+            el.setAttribute(QStringLiteral("faviconWidth"), d->m_faviconInfo.width);
+        }
+        if (d->m_faviconInfo.height != -1) {
+            el.setAttribute(QStringLiteral("faviconHeight"), d->m_faviconInfo.height);
+        }
+    }
+    if (!d->m_logoInfo.imageUrl.isEmpty()) {
+        el.setAttribute(QStringLiteral("logoUrl"), d->m_logoInfo.imageUrl);
+        if (d->m_logoInfo.width != -1) {
+            el.setAttribute(QStringLiteral("logoWidth"), d->m_logoInfo.width);
+        }
+        if (d->m_logoInfo.height != -1) {
+            el.setAttribute(QStringLiteral("logoHeight"), d->m_logoInfo.height);
+        }
+    }
     el.setAttribute(QStringLiteral("maxArticleNumber"), d->m_maxArticleNumber);
     el.setAttribute(QStringLiteral("type"), QStringLiteral("rss"));   // despite some additional fields, it is still "rss" OPML
     el.setAttribute(QStringLiteral("version"), QStringLiteral("RSS"));
@@ -562,9 +609,9 @@ void Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchOnly)
             interval = Settings::autoFetchInterval() * 60;
         }
 
-        uint lastFetch = d->m_archive->lastFetch().toSecsSinceEpoch();
+        const uint lastFetch = d->m_archive->lastFetch().toSecsSinceEpoch();
 
-        uint now = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
+        const uint now = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
 
         if (interval > 0 && (now - lastFetch) >= static_cast<uint>(interval)) {
             queue->addFeed(this);
@@ -574,10 +621,10 @@ void Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchOnly)
 
 void Feed::slotAddFeedIconListener()
 {
-    if (d->m_faviconUrl.isEmpty()) {
+    if (d->m_faviconInfo.imageUrl.isEmpty()) {
         loadFavicon(d->m_xmlUrl, true);
     } else {
-        loadFavicon(d->m_faviconUrl, false);
+        loadFavicon(d->m_faviconInfo.imageUrl, false);
     }
 }
 
@@ -661,7 +708,7 @@ bool Feed::usesExpiryByAge() const
 
 bool Feed::isExpired(const Article &a) const
 {
-    QDateTime now = QDateTime::currentDateTime();
+    const QDateTime now = QDateTime::currentDateTime();
     int expiryAge = -1;
 // check whether the feed uses the global default and the default is limitArticleAge
     if (d->m_archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleAge) {
@@ -715,16 +762,11 @@ void Feed::tryFetch()
     d->m_fetchErrorCode = Syndication::Success;
 
     d->m_loader = Syndication::Loader::create(this, SLOT(fetchCompleted(Syndication::Loader*,
-                                                                      Syndication::FeedPtr,
-                                                                      Syndication::ErrorCode)));
+                                                                        Syndication::FeedPtr,
+                                                                        Syndication::ErrorCode)));
     d->m_loader->loadFrom(QUrl(d->m_xmlUrl), new FeedRetriever());
 }
 
-void Feed::slotImageFetched(const QPixmap &image)
-{
-    setImage(image);
-}
-
 void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Syndication::ErrorCode status)
 {
     // Note that loader instances delete themselves
@@ -750,9 +792,11 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
 
     loadArticles(); // TODO: make me fly: make this delayed
 
-#if SYNDICATION_VERSION >= QT_VERSION_CHECK(5,65,0)
+#if SYNDICATION_VERSION >= QT_VERSION_CHECK(5, 65, 0)
     if (!doc->icon().isNull() && !doc->icon()->url().isEmpty()) {
         loadFavicon(doc->icon()->url(), false);
+        d->m_faviconInfo.width = doc->icon()->width();
+        d->m_faviconInfo.height = doc->icon()->height();
     } else {
         loadFavicon(xmlUrl(), true);
     }
@@ -761,9 +805,10 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
 #endif
     d->m_fetchErrorCode = Syndication::Success;
 
-    if (d->m_imagePixmap.isNull()) {
-        const QString imageFileName = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/akregator/Media/") + Utils::fileNameForUrl(d->m_xmlUrl) + QLatin1String(".png");
-        d->m_imagePixmap = QPixmap(imageFileName, "PNG");
+    if (!doc->image().isNull()) {
+        d->m_logoInfo.imageUrl = doc->image()->url();
+        d->m_logoInfo.width = doc->image()->width();
+        d->m_logoInfo.height = doc->image()->height();
     }
 
     if (title().isEmpty()) {
@@ -824,17 +869,12 @@ void Feed::setFavicon(const QIcon &icon)
     nodeModified();
 }
 
-void Feed::setImage(const QPixmap &p)
+void Feed::setLogoInfo(const ImageInfo &image)
 {
-    if (p.isNull()) {
-        return;
+    if (d->m_logoInfo != image) {
+        d->m_logoInfo = image;
+        nodeModified();
     }
-    d->m_imagePixmap = p;
-    const QString filename = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/akregator/Media/") + Utils::fileNameForUrl(d->m_xmlUrl) + QLatin1String(".png");
-    QFileInfo fileInfo(filename);
-    QDir().mkpath(fileInfo.absolutePath());
-    d->m_imagePixmap.save(filename, "PNG");
-    nodeModified();
 }
 
 Feed::ArchiveMode Feed::archiveMode() const
@@ -936,21 +976,21 @@ void Feed::doArticleNotification()
     if (!d->m_addedArticlesNotify.isEmpty()) {
         // copy list, otherwise the refcounting in Article::Private breaks for
         // some reason (causing segfaults)
-        QVector<Article> l = d->m_addedArticlesNotify;
+        const QVector<Article> l = d->m_addedArticlesNotify;
         Q_EMIT signalArticlesAdded(this, l);
         d->m_addedArticlesNotify.clear();
     }
     if (!d->m_updatedArticlesNotify.isEmpty()) {
         // copy list, otherwise the refcounting in Article::Private breaks for
         // some reason (causing segfaults)
-        QVector<Article> l = d->m_updatedArticlesNotify;
+        const QVector<Article> l = d->m_updatedArticlesNotify;
         Q_EMIT signalArticlesUpdated(this, l);
         d->m_updatedArticlesNotify.clear();
     }
     if (!d->m_removedArticlesNotify.isEmpty()) {
         // copy list, otherwise the refcounting in Article::Private breaks for
         // some reason (causing segfaults)
-        QVector<Article> l = d->m_removedArticlesNotify;
+        const QVector<Article> l = d->m_removedArticlesNotify;
         Q_EMIT signalArticlesRemoved(this, l);
         d->m_removedArticlesNotify.clear();
     }
@@ -986,3 +1026,15 @@ void Feed::enforceLimitArticleNumber()
         }
     }
 }
+
+bool Feed::ImageInfo::operator==(const Feed::ImageInfo &other) const
+{
+    return other.width == width
+           && other.height == height
+           && other.imageUrl == imageUrl;
+}
+
+bool Feed::ImageInfo::operator!=(const Feed::ImageInfo &other) const
+{
+    return !ImageInfo::operator==(other);
+}
