@@ -42,8 +42,6 @@
 #include <QSet>
 #include <QElapsedTimer>
 
-#include <cassert>
-
 using namespace Akregator;
 class Q_DECL_HIDDEN FeedList::Private
 {
@@ -560,7 +558,7 @@ QStringList FeedListManagementImpl::feeds(const QString &catId) const
             urls.insert(i->xmlUrl());
         }
     }
-    return urls.toList();
+    return urls.values();
 }
 
 void FeedListManagementImpl::addFeed(const QString &url, const QString &catId)
