@@ -43,8 +43,8 @@ FeedPropertiesWidget::FeedPropertiesWidget(QWidget *parent, const QString &name)
     connect(cb_updateInterval, &QCheckBox::toggled, updateComboBox, &QComboBox::setEnabled);
     connect(cb_updateInterval, &QCheckBox::toggled, updateLabel, &QLabel::setEnabled);
     connect(cb_updateInterval, &QCheckBox::toggled, this, &FeedPropertiesWidget::slotUpdateCheckBoxToggled);
-    connect(updateComboBox, QOverload<int>::of(&QComboBox::activated), this, &FeedPropertiesWidget::slotUpdateComboBoxActivated);
-    connect(updateSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &FeedPropertiesWidget::slotUpdateComboBoxLabels);
+    connect(updateComboBox, qOverload<int>(&QComboBox::activated), this, &FeedPropertiesWidget::slotUpdateComboBoxActivated);
+    connect(updateSpinBox, qOverload<int>(&QSpinBox::valueChanged), this, &FeedPropertiesWidget::slotUpdateComboBoxLabels);
     connect(rb_limitArticleAge, &QRadioButton::toggled, sb_maxArticleAge, &KPluralHandlingSpinBox::setEnabled);
     connect(rb_limitArticleNumber, &QRadioButton::toggled, sb_maxArticleNumber, &KPluralHandlingSpinBox::setEnabled);
 }
@@ -123,6 +123,7 @@ void FeedPropertiesDialog::accept()
     m_feed->setUseNotification(useNotification());
     m_feed->setLoadLinkedWebsite(loadLinkedWebsite());
     m_feed->setNotificationMode(true);
+    m_feed->setComment(comment());
 
     QDialog::accept();
 }
@@ -155,9 +156,20 @@ void FeedPropertiesDialog::setFeed(Feed *feed)
     setMarkImmediatelyAsRead(feed->markImmediatelyAsRead());
     setUseNotification(feed->useNotification());
     setLoadLinkedWebsite(feed->loadLinkedWebsite());
+    setComment(feed->comment());
     slotSetWindowTitle(feedName());
 }
 
+QString FeedPropertiesDialog::comment() const
+{
+    return widget->commentEdit->text();
+}
+
+void FeedPropertiesDialog::setComment(const QString &comment)
+{
+    widget->commentEdit->setText(comment);
+}
+
 QString FeedPropertiesDialog::feedName() const
 {
     return widget->feedNameEdit->text();
