@@ -70,17 +70,17 @@ public Q_SLOTS:
     void accept() override;
 
 protected:
-    QString comment() const;
-    QString feedName() const;
-    QString url() const;
-    bool autoFetch() const;
-    int fetchInterval() const;
-    Feed::ArchiveMode archiveMode() const;
-    int maxArticleAge() const;
-    int maxArticleNumber() const;
-    bool markImmediatelyAsRead() const;
-    bool useNotification() const;
-    bool loadLinkedWebsite() const;
+    Q_REQUIRED_RESULT QString comment() const;
+    Q_REQUIRED_RESULT QString feedName() const;
+    Q_REQUIRED_RESULT QString url() const;
+    Q_REQUIRED_RESULT bool autoFetch() const;
+    Q_REQUIRED_RESULT int fetchInterval() const;
+    Q_REQUIRED_RESULT Feed::ArchiveMode archiveMode() const;
+    Q_REQUIRED_RESULT int maxArticleAge() const;
+    Q_REQUIRED_RESULT int maxArticleNumber() const;
+    Q_REQUIRED_RESULT bool markImmediatelyAsRead() const;
+    Q_REQUIRED_RESULT bool useNotification() const;
+    Q_REQUIRED_RESULT bool loadLinkedWebsite() const;
 
     void setFeedName(const QString &title);
     void setUrl(const QString &url);
