@@ -41,7 +41,7 @@ class ArticleGrantleeObject : public QObject
     Q_PROPERTY(QString actionToken READ actionToken)
 
 public:
-    explicit ArticleGrantleeObject(const QUrl &imageDir, const Article &article, ArticleFormatter::IconOption icon, QObject *parent = nullptr);
+    explicit ArticleGrantleeObject(const Article &article, ArticleFormatter::IconOption icon, QObject *parent = nullptr);
     ~ArticleGrantleeObject();
 
     enum ArticleStatus {
@@ -53,30 +53,29 @@ public:
 
     Akregator::ArticleGrantleeObject::ArticleStatus articleStatus() const;
 
-    QString strippedTitle() const;
-    QString author() const;
-    QString content() const;
-    QString articleLinkUrl() const;
-    QString articlePubDate() const;
-    QString enclosure() const;
-    QString articleCompleteStoryLink() const;
-    QString imageFeed() const;
+    Q_REQUIRED_RESULT QString strippedTitle() const;
+    Q_REQUIRED_RESULT QString author() const;
+    Q_REQUIRED_RESULT QString content() const;
+    Q_REQUIRED_RESULT QString articleLinkUrl() const;
+    Q_REQUIRED_RESULT QString articlePubDate() const;
+    Q_REQUIRED_RESULT QString enclosure() const;
+    Q_REQUIRED_RESULT QString articleCompleteStoryLink() const;
+    Q_REQUIRED_RESULT QString imageFeed() const;
 
     //Action
-    QString deleteAction() const;
-    QString markAsReadAction() const;
-    QString markAsUnreadAction() const;
-    QString markAsImportantAction() const;
-    QString sendUrlAction() const;
-    QString sendFileAction() const;
+    Q_REQUIRED_RESULT QString deleteAction() const;
+    Q_REQUIRED_RESULT QString markAsReadAction() const;
+    Q_REQUIRED_RESULT QString markAsUnreadAction() const;
+    Q_REQUIRED_RESULT QString markAsImportantAction() const;
+    Q_REQUIRED_RESULT QString sendUrlAction() const;
+    Q_REQUIRED_RESULT QString sendFileAction() const;
 
-    bool important() const;
-    QString actionToken() const;
+    Q_REQUIRED_RESULT bool important() const;
+    Q_REQUIRED_RESULT QString actionToken() const;
 
 private:
     Article mArticle;
     ArticleFormatter::IconOption mArticleFormatOption;
-    QUrl mImageDir;
 };
 }
 #endif // ARTICLEGRANTLEEOBJECT_H
