@@ -32,13 +32,13 @@
 #include <QString>
 using namespace Akregator;
 
-DefaultCombinedViewFormatter::DefaultCombinedViewFormatter(const QString &grantleeDirectory, const QUrl &imageDir, QPaintDevice *device)
+DefaultCombinedViewFormatter::DefaultCombinedViewFormatter(const QString &grantleeDirectory, QPaintDevice *device)
     : ArticleFormatter()
 {
     const QString combinedPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
                                                         QStringLiteral("akregator/grantleetheme/%1/").arg(grantleeDirectory),
                                                         QStandardPaths::LocateDirectory);
-    mGrantleeViewFormatter = new GrantleeViewFormatter(QStringLiteral("combinedview.html"), combinedPath, imageDir, device->logicalDpiY());
+    mGrantleeViewFormatter = new GrantleeViewFormatter(QStringLiteral("combinedview.html"), combinedPath, device->logicalDpiY());
 }
 
 DefaultCombinedViewFormatter::~DefaultCombinedViewFormatter()
