@@ -19,13 +19,14 @@
 
 #include "grantleeutil.h"
 #include "feed.h"
-#include "utils.h"
-
-QString Akregator::GrantleeUtil::imageFeed(const Feed *feed, const QUrl &imageDir)
+#include <QDebug>
+QString Akregator::GrantleeUtil::imageFeed(const Feed *feed)
 {
-    QString file = Akregator::Utils::fileNameForUrl(feed->xmlUrl());
-    QUrl u(imageDir);
-    u = u.adjusted(QUrl::RemoveFilename);
-    u.setPath(u.path() + file);
-    return QStringLiteral("<a href=\"%1\"><img class=\"headimage\" src=\"%2.png\"></a>\n").arg(feed->htmlUrl(), u.url());
+    if (feed->logoInfo().height != -1 && feed->logoInfo().width != -1) {
+        return QStringLiteral("<a href=\"%1\"><img class=\"headimage\" src=\"%2\" height=\"%3\" width=\"%4\"></a>\n").arg(feed->htmlUrl(),
+                                                                                                                          feed->logoInfo().imageUrl)
+               .arg(feed->logoInfo().height)
+               .arg(feed->logoInfo().width);
+    }
+    return QStringLiteral("<a href=\"%1\"><img class=\"headimage\" src=\"%2\"></a>\n").arg(feed->htmlUrl(), feed->logoInfo().imageUrl);
 }
