@@ -23,9 +23,8 @@
 #include <QUrl>
 namespace Akregator {
 class Feed;
-namespace GrantleeUtil
-{
-QString imageFeed(const Feed *feed, const QUrl &imageDir);
+namespace GrantleeUtil {
+Q_REQUIRED_RESULT QString imageFeed(const Feed *feed);
 }
 }
 
