@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ MainFrame::MainFrame(QWidget *parent, QWidget *visibleWidget)
 {
     setRemovable(false);
     QGridLayout *layout = new QGridLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(visibleWidget, 0, 0);
 }
 
