@@ -51,8 +51,6 @@
 #include "openurlrequest.h"
 #include "utils/temporaryvalue.h"
 
-#include <cassert>
-
 using namespace Akregator;
 
 class Q_DECL_HIDDEN TabWidget::Private
@@ -62,15 +60,12 @@ private:
 
 public:
     explicit Private(TabWidget *qq) : q(qq)
-        , currentMaxLength(30)
-        , currentItem(nullptr)
-        , tabsClose(nullptr)
     {
     }
 
     QHash<QWidget *, Frame *> frames;
     QHash<int, Frame *> framesById;
-    int currentMaxLength;
+    int currentMaxLength = 30;
     QWidget *currentItem = nullptr;
     QToolButton *tabsClose = nullptr;
 
